pub enum IoMode {
Live,
Replay,
}Expand description
Whether a run is allowed to perform live IO or must replay from recorded facts/artifacts.
Variants
Live
Execute side effects through live transports and record replay inputs.
Replay
Disallow live side effects and resolve deterministic IO from recorded facts.