pub struct OpBoundary {
pub op_path: OpPath,
pub phase: String,
}Expand description
Recommended payload for domain events that mark op boundaries.
Fields
op_path: OpPathNested operation path being reported.
phase: StringBoundary phase, typically values such as started or completed.