pub struct ExecPolicy {
pub allow_prefixes: Vec<String>,
}Expand description
Policy used by the exec transport to constrain which programs may be executed.
Fields
allow_prefixes: Vec<String>Canonical path prefixes that executable targets must reside under.