StdinWriteError

Struct StdinWriteError 

pub struct StdinWriteError {
    pub kind: ErrorKind,
}
Reduced IO error information captured while interacting with child stdin.

Fields

kind: ErrorKind

std::io::ErrorKind captured while writing to or closing child stdin.