Module state

Module state 

State trait and outcome types used by planned execution nodes.

Structs

StateOutcome
Result returned by a successful state handler.

Enums

SnapshotPolicy
Indicates whether the engine should snapshot context after the state.

Traits

State
Note:

Type Aliases

DynState
Shared trait-object form used by planners and executors.