pub enum SnapshotPolicy {
Never,
OnSuccess,
Always,
}Expand description
Indicates whether the engine should snapshot context after the state.
Variants
Never
Do not request an additional snapshot for this state outcome.
OnSuccess
Request a snapshot only when the state succeeds.
Always
Request a snapshot even if the state fails.