pub struct ProcessRunResult {
pub status: ExitStatus,
pub stdout: CollectedStream,
pub stderr: CollectedStream,
pub stdin_write_error: Option<StdinWriteError>,
pub stdin_close_error: Option<StdinWriteError>,
}Expand description
Result of a completed child-process execution.
Fields
status: ExitStatusFinal exit status returned by the child process.
stdout: CollectedStreamBounded stdout capture collected during execution.
stderr: CollectedStreamBounded stderr capture collected during execution.
stdin_write_error: Option<StdinWriteError>Error returned while writing stdin, if the write failed after spawn succeeded.
stdin_close_error: Option<StdinWriteError>Error returned while closing stdin, if shutdown failed after writing.