pub struct StreamLimit {
pub max_stdout_bytes: usize,
pub max_stderr_bytes: usize,
}Expand description
Output limits applied while collecting child stdout and stderr.
Fields
max_stdout_bytes: usizeMaximum number of stdout bytes retained in memory before truncation is reported.
max_stderr_bytes: usizeMaximum number of stderr bytes retained in memory before truncation is reported.