pub struct DefaultExecutionEngine { /* private fields */ }Expand description
Default runtime implementation for the unstable v4 execution engine.
The engine validates the run contract, rehydrates facts from prior events, and executes states in topological order with retry/resume semantics.
Implementations
Sourceimpl DefaultExecutionEngine
impl DefaultExecutionEngine
Sourcepub fn new(resolver: Arc<dyn PlanResolver>) -> Self
pub fn new(resolver: Arc<dyn PlanResolver>) -> Self
Creates an engine that resolves plans with resolver and rejects live IO by default.
Sourcepub fn with_live_transport_factory(
self,
factory: Arc<dyn LiveIoTransportFactory>,
) -> Self
pub fn with_live_transport_factory( self, factory: Arc<dyn LiveIoTransportFactory>, ) -> Self
Installs the live IO transport factory used for state execution in live mode.
Sourcepub fn with_failpoints(self, failpoints: EngineFailpoints) -> Self
pub fn with_failpoints(self, failpoints: EngineFailpoints) -> Self
Enables test failpoints for the returned engine instance.