State trait and outcome types used by planned execution nodes.
Structs
- State
Outcome - Result returned by a successful state handler.
Enums
- Snapshot
Policy - Indicates whether the engine should snapshot context after the state.
Traits
- State
- Note:
Type Aliases
- DynState
- Shared trait-object form used by planners and executors.